@@ -34,11 +34,11 @@ class FITS_record(object):
 
         start : int, optional
            The starting column in the row associated with this object.
-           Used for subsetting the columns of the FITS_rec object.
+           Used for subsetting the columns of the `FITS_rec` object.
 
         end : int, optional
            The ending column in the row associated with this object.
-           Used for subsetting the columns of the FITS_rec object.
+           Used for subsetting the columns of the `FITS_rec` object.
         """
 
         # For backward compatibility...
@@ -150,8 +150,8 @@ class FITS_rec(np.recarray):
     """
     FITS record array class.
 
-    `FITS_rec` is the data part of a table HDU's data part.  This is a
-    layer over the `recarray`, so we can deal with scaled columns.
+    `FITS_rec` is the data part of a table HDU's data part.  This is a layer
+    over the `~numpy.recarray`, so we can deal with scaled columns.
 
     It inherits all of the standard methods from `numpy.ndarray`.
     """
@@ -323,7 +323,9 @@ class FITS_rec(np.recarray):
     @property
     def columns(self):
         """
-        A user-visible accessor for the coldefs.  See ticket #44.
+        A user-visible accessor for the coldefs.
+
+        See https://trac.assembla.com/pyfits/ticket/44
         """
 
         return self._coldefs
@@ -564,10 +566,37 @@ class FITS_rec(np.recarray):
                 widths.append(f[1])
             loc.append(loc[-1] + super(FITS_rec, self).field(idx).itemsize)
 
+        # Running total for the new heap size
+        heapsize = 0
+
         for indx in range(len(self.dtype.names)):
             recformat = self._coldefs._recformats[indx]
             field = super(FITS_rec, self).field(indx)
 
+            # add the location offset of the heap area for each
+            # variable length column
+            if isinstance(recformat, _FormatP):
+                # Irritatingly, this can return a different dtype than just
+                # doing np.dtype(recformat.dtype); but this returns the results
+                # that we want.  For example if recformat.dtype is 'a' we want
+                # an array of characters.
+                dtype = np.array([], dtype=recformat.dtype).dtype
+
+                if self._convert[indx] is not None:
+                    # The VLA has potentially been updated, so we need to
+                    # update the array descriptors
+                    field[:] = 0  # reset
+                    npts = [len(arr) for arr in self._convert[indx]]
+
+                    field[:len(npts), 0] = npts
+                    field[1:, 1] = (np.add.accumulate(field[:-1, 0]) *
+                                    dtype.itemsize)
+                    field[:, 1][:] += heapsize
+
+                heapsize += field[:, 0].sum() * dtype.itemsize
+                # Even if this VLA has not been read, we need to include
+                # the size of its constituent arrays in the heap size total
+
             if self._convert[indx] is None:
                 continue
 
@@ -578,24 +607,6 @@ class FITS_rec(np.recarray):
             (_str, _bool, _number, _scale, _zero, bscale, bzero, dim) = \
                 self._get_scale_factors(indx)
 
-            # add the location offset of the heap area for each
-            # variable length column
-            if isinstance(recformat, _FormatP):
-                # Reset the heapsize and recompute it starting from the first P
-                # column
-                if indx == 0:
-                    self._heapsize = 0
-
-                field[:] = 0  # reset
-                npts = map(len, self._convert[indx])
-
-                dtype = np.array([], dtype=recformat.dtype).dtype
-                field[:len(npts), 0] = npts
-                field[1:, 1] = (np.add.accumulate(field[:-1, 0]) *
-                                dtype.itemsize)
-                field[:, 1][:] += self._heapsize
-                self._heapsize += field[:, 0].sum() * dtype.itemsize
-
             # conversion for both ASCII and binary tables
             if _number or _str:
                 if _number and (_scale or _zero):
@@ -685,3 +696,6 @@ class FITS_rec(np.recarray):
                 field[:] = np.choose(self._convert[indx],
                                      (np.array([ord('F')], dtype=np.int8)[0],
                                       np.array([ord('T')], dtype=np.int8)[0]))
+
+        # Store the updated heapsize
+        self._heapsize = heapsize
