@@ -35,9 +35,9 @@ class StreamingHDU(object):
         Parameters
         ----------
         name : file path, file object, or file like object
-            The file to which the header and data will be streamed.
-            If opened, the file object must be opened for append
-            (ab+).
+            The file to which the header and data will be streamed.  If opened,
+            the file object must be opened in a writeable binary mode such as
+            'wb' or 'ab+'.
 
         header : `Header` instance
             The header object associated with the data to be written
@@ -150,17 +150,16 @@ class StreamingHDU(object):
 
         Notes
         -----
-        Only the amount of data specified in the header provided to
-        the class constructor may be written to the stream.  If the
-        provided data would cause the stream to overflow, an `IOError`
-        exception is raised and the data is not written.  Once
-        sufficient data has been written to the stream to satisfy the
-        amount specified in the header, the stream is padded to fill a
-        complete FITS block and no more data will be accepted.  An
-        attempt to write more data after the stream has been filled
-        will raise an `IOError` exception.  If the dtype of the input
-        data does not match what is expected by the header, a
-        `TypeError` exception is raised.
+        Only the amount of data specified in the header provided to the class
+        constructor may be written to the stream.  If the provided data would
+        cause the stream to overflow, an `IOError` exception is raised and the
+        data is not written.  Once sufficient data has been written to the
+        stream to satisfy the amount specified in the header, the stream is
+        padded to fill a complete FITS block and no more data will be accepted.
+        An attempt to write more data after the stream has been filled will
+        raise an `IOError` exception.  If the dtype of the input data does not
+        match what is expected by the header, a `TypeError` exception is
+        raised.
         """
 
         curDataSize = self._ffo.tell() - self._datLoc
